@@ -71,8 +71,8 @@ class HostContext(object):
 
     def cd(self, path, expand=False):
         """
-        Execute commands in this directory.
-        Nesting of cd-statements is allowed.
+        Execute commands in this directory. Nesting of cd-statements is
+        allowed.
 
         ::
 
@@ -93,7 +93,8 @@ class HostContext(object):
     def _chdir(self, path):
         """ Move to this directory. Not to be used together with the `cd` context manager. """
         # NOTE: This is used by the sftp shell.
-        self._path = [ (os.path.join(* self._path + [path]), False) ]
+        # TODO: check 'expand' flags.
+        self._path = [ (os.path.join(* [p[0] for p in self._path] + [path]), False) ]
 
     def env(self, variable, value, escape=True):
         """
@@ -800,8 +801,9 @@ class Host(object):
     # Some simple wrappers for the commands
 
     def sudo(self, *args, **kwargs):
-        """
-        Run this command using sudo.
+        """sudo(command, use_sudo=False, sandbox=False, interactive=True, user=None, ignore_exit_status=False, initial_input=None, silent=False)
+
+        Wrapper around :func:`~deployer.host.base.Host.run` which uses ``sudo``.
         """
         kwargs['use_sudo'] = True
         return self.run(*args, **kwargs)
